@@ -4,8 +4,8 @@ Package provides functionality for importing from BPMN 2.0 XML to graph represen
 """
 from xml.dom import minidom
 
-import bpmn_python.bpmn_python_consts as consts
 import bpmn_python.bpmn_import_utils as utils
+import bpmn_python.bpmn_python_consts as consts
 
 
 class BpmnDiagramGraphImport(object):
@@ -54,7 +54,7 @@ class BpmnDiagramGraphImport(object):
         else:
             message_flows = {}
 
-        participants = None
+        participants = []
         if consts.Consts.participants in collaboration:
             participants = collaboration[consts.Consts.participants]
 
@@ -87,15 +87,16 @@ class BpmnDiagramGraphImport(object):
             if element.nodeType != element.TEXT_NODE:
                 tag_name = utils.BpmnImportUtils.remove_namespace_from_tag_name(element.tagName)
                 if tag_name == consts.Consts.participant:
-                    BpmnDiagramGraphImport.import_participant_element(participants_dict, element)
+                    BpmnDiagramGraphImport.import_participant_element(diagram_graph, participants_dict, element)
                 elif tag_name == consts.Consts.message_flow:
                     BpmnDiagramGraphImport.import_message_flow_to_graph(diagram_graph, message_flows_dict, element)
 
     @staticmethod
-    def import_participant_element(participants_dictionary, participant_element):
+    def import_participant_element(diagram_graph, participants_dictionary, participant_element):
         """
         Adds 'participant' element to the collaboration dictionary.
 
+        :param diagram_graph: NetworkX graph representing a BPMN process diagram,
         :param participants_dictionary: dictionary with participant element attributes. Key is participant ID, value
         is a dictionary of participant attributes,
         :param participant_element: object representing a BPMN XML 'participant' element.
@@ -103,6 +104,10 @@ class BpmnDiagramGraphImport(object):
         participant_id = participant_element.getAttribute(consts.Consts.id)
         name = participant_element.getAttribute(consts.Consts.name)
         process_ref = participant_element.getAttribute(consts.Consts.process_ref)
+        if participant_element.getAttribute(consts.Consts.process_ref) == '':
+            diagram_graph.add_node(participant_id)
+            diagram_graph.node[participant_id][consts.Consts.type] = consts.Consts.participant
+            diagram_graph.node[participant_id][consts.Consts.process] = participant_id
         participants_dictionary[participant_id] = {consts.Consts.name: name, consts.Consts.process_ref: process_ref}
 
     @staticmethod
@@ -156,36 +161,8 @@ class BpmnDiagramGraphImport(object):
             for element in utils.BpmnImportUtils.iterate_elements(process_element):
                 if element.nodeType != element.TEXT_NODE:
                     tag_name = utils.BpmnImportUtils.remove_namespace_from_tag_name(element.tagName)
-                    if tag_name == consts.Consts.task:
-                        BpmnDiagramGraphImport.import_task_to_graph(diagram_graph, process_id, process_attributes,
-                                                                    element)
-                    elif tag_name == consts.Consts.subprocess:
-                        BpmnDiagramGraphImport.import_subprocess_to_graph(diagram_graph, process_id,
-                                                                          process_attributes, element)
-                    elif tag_name == consts.Consts.inclusive_gateway or tag_name == consts.Consts.exclusive_gateway:
-                        BpmnDiagramGraphImport.import_incl_or_excl_gateway_to_graph(diagram_graph, process_id,
-                                                                                    process_attributes, element)
-                    elif tag_name == consts.Consts.parallel_gateway:
-                        BpmnDiagramGraphImport.import_parallel_gateway_to_graph(diagram_graph, process_id,
-                                                                                process_attributes, element)
-                    elif tag_name == consts.Consts.event_based_gateway:
-                        BpmnDiagramGraphImport.import_event_based_gateway_to_graph(diagram_graph, process_id,
-                                                                                   process_attributes, element)
-                    elif tag_name == consts.Consts.complex_gateway:
-                        BpmnDiagramGraphImport.import_complex_gateway_to_graph(diagram_graph, process_id,
-                                                                               process_attributes, element)
-                    elif tag_name == consts.Consts.start_event:
-                        BpmnDiagramGraphImport.import_start_event_to_graph(diagram_graph, process_id,
-                                                                           process_attributes, element)
-                    elif tag_name == consts.Consts.end_event:
-                        BpmnDiagramGraphImport.import_end_event_to_graph(diagram_graph, process_id,
-                                                                         process_attributes, element)
-                    elif tag_name == consts.Consts.intermediate_catch_event:
-                        BpmnDiagramGraphImport.import_intermediate_catch_event_to_graph(diagram_graph, process_id,
-                                                                                        process_attributes, element)
-                    elif tag_name == consts.Consts.intermediate_throw_event:
-                        BpmnDiagramGraphImport.import_intermediate_throw_event_to_graph(diagram_graph, process_id,
-                                                                                        process_attributes, element)
+                    BpmnDiagramGraphImport.__import_element_by_tag_name(diagram_graph, sequence_flows, process_id,
+                                                                        process_attributes, element, tag_name)
 
             for flow in utils.BpmnImportUtils.iterate_elements(process_element):
                 if flow.nodeType != flow.TEXT_NODE:
@@ -194,6 +171,44 @@ class BpmnDiagramGraphImport(object):
                         BpmnDiagramGraphImport.import_sequence_flow_to_graph(diagram_graph, sequence_flows, process_id,
                                                                              flow)
 
+    @staticmethod
+    def __import_element_by_tag_name(diagram_graph, sequence_flows, process_id, process_attributes, element, tag_name):
+        if tag_name == consts.Consts.task \
+                or tag_name == consts.Consts.user_task \
+                or tag_name == consts.Consts.service_task \
+                or tag_name == consts.Consts.manual_task:
+            BpmnDiagramGraphImport.import_task_to_graph(diagram_graph, process_id, process_attributes, element)
+        elif tag_name == consts.Consts.subprocess:
+            BpmnDiagramGraphImport.import_subprocess_to_graph(diagram_graph, sequence_flows, process_id,
+                                                              process_attributes, element)
+        elif tag_name == consts.Consts.data_object:
+            BpmnDiagramGraphImport.import_data_object_to_graph(diagram_graph, process_id, process_attributes, element)
+        elif tag_name == consts.Consts.inclusive_gateway or tag_name == consts.Consts.exclusive_gateway:
+            BpmnDiagramGraphImport.import_incl_or_excl_gateway_to_graph(diagram_graph, process_id, process_attributes,
+                                                                        element)
+        elif tag_name == consts.Consts.parallel_gateway:
+            BpmnDiagramGraphImport.import_parallel_gateway_to_graph(diagram_graph, process_id, process_attributes,
+                                                                    element)
+        elif tag_name == consts.Consts.event_based_gateway:
+            BpmnDiagramGraphImport.import_event_based_gateway_to_graph(diagram_graph, process_id, process_attributes,
+                                                                       element)
+        elif tag_name == consts.Consts.complex_gateway:
+            BpmnDiagramGraphImport.import_complex_gateway_to_graph(diagram_graph, process_id, process_attributes,
+                                                                   element)
+        elif tag_name == consts.Consts.start_event:
+            BpmnDiagramGraphImport.import_start_event_to_graph(diagram_graph, process_id, process_attributes, element)
+        elif tag_name == consts.Consts.end_event:
+            BpmnDiagramGraphImport.import_end_event_to_graph(diagram_graph, process_id, process_attributes, element)
+        elif tag_name == consts.Consts.intermediate_catch_event:
+            BpmnDiagramGraphImport.import_intermediate_catch_event_to_graph(diagram_graph, process_id,
+                                                                            process_attributes, element)
+        elif tag_name == consts.Consts.intermediate_throw_event:
+            BpmnDiagramGraphImport.import_intermediate_throw_event_to_graph(diagram_graph, process_id,
+                                                                            process_attributes, element)
+        elif tag_name == consts.Consts.boundary_event:
+            BpmnDiagramGraphImport.import_boundary_event_to_graph(diagram_graph, process_id, process_attributes,
+                                                                  element)
+
     @staticmethod
     def import_lane_set_element(process_attributes, lane_set_element, plane_element):
         """
@@ -309,7 +324,7 @@ class BpmnDiagramGraphImport(object):
         process_elements_dict[process_id] = process_element_attributes
 
     @staticmethod
-    def import_flownode_to_graph(bpmn_graph, process_id, process_attributes, element):
+    def import_flow_node_to_graph(bpmn_graph, process_id, process_attributes, flow_node_element):
         """
         Adds a new node to graph.
         Input parameter is object of class xml.dom.Element.
@@ -323,37 +338,42 @@ class BpmnDiagramGraphImport(object):
         :param process_id: string object, representing an ID of process element,
         :param process_attributes: dictionary that holds attribute values of 'process' element, which is parent of
         imported flow node,
-        :param element: object representing a BPMN XML element corresponding to given flownode,
+        :param flow_node_element: object representing a BPMN XML element corresponding to given flownode,
         """
-        element_id = element.getAttribute(consts.Consts.id)
+        element_id = flow_node_element.getAttribute(consts.Consts.id)
         bpmn_graph.add_node(element_id)
+        bpmn_graph.node[element_id][consts.Consts.id] = element_id
         bpmn_graph.node[element_id][consts.Consts.type] = \
-            utils.BpmnImportUtils.remove_namespace_from_tag_name(element.tagName)
+            utils.BpmnImportUtils.remove_namespace_from_tag_name(flow_node_element.tagName)
         bpmn_graph.node[element_id][consts.Consts.node_name] = \
-            element.getAttribute(consts.Consts.name) if element.hasAttribute(consts.Consts.name) else ""
+            flow_node_element.getAttribute(consts.Consts.name) \
+                if flow_node_element.hasAttribute(consts.Consts.name) \
+                else ""
         bpmn_graph.node[element_id][consts.Consts.process] = process_id
         process_attributes[consts.Consts.node_ids].append(element_id)
 
         # add incoming flow node list
-        incoming_xml = element.getElementsByTagNameNS("*", consts.Consts.incoming_flows)
-        length = len(incoming_xml)
-        incoming_list = [None] * length
-        for index in range(length):
-            incoming_tmp = incoming_xml[index].firstChild.nodeValue
-            incoming_list[index] = incoming_tmp
-        bpmn_graph.node[element_id][consts.Consts.incoming_flows] = incoming_list
+        incoming_list = []
+        for tmp_element in utils.BpmnImportUtils.iterate_elements(flow_node_element):
+            if tmp_element.nodeType != tmp_element.TEXT_NODE:
+                tag_name = utils.BpmnImportUtils.remove_namespace_from_tag_name(tmp_element.tagName)
+                if tag_name == consts.Consts.incoming_flow:
+                    incoming_value = tmp_element.firstChild.nodeValue
+                    incoming_list.append(incoming_value)
+        bpmn_graph.node[element_id][consts.Consts.incoming_flow] = incoming_list
 
         # add outgoing flow node list
-        outgoing_xml = element.getElementsByTagNameNS("*", consts.Consts.outgoing_flows)
-        length = len(outgoing_xml)
-        outgoing_list = [None] * length
-        for index in range(length):
-            outgoing_tmp = outgoing_xml[index].firstChild.nodeValue
-            outgoing_list[index] = outgoing_tmp
-        bpmn_graph.node[element_id][consts.Consts.outgoing_flows] = outgoing_list
+        outgoing_list = []
+        for tmp_element in utils.BpmnImportUtils.iterate_elements(flow_node_element):
+            if tmp_element.nodeType != tmp_element.TEXT_NODE:
+                tag_name = utils.BpmnImportUtils.remove_namespace_from_tag_name(tmp_element.tagName)
+                if tag_name == consts.Consts.outgoing_flow:
+                    outgoing_value = tmp_element.firstChild.nodeValue
+                    outgoing_list.append(outgoing_value)
+        bpmn_graph.node[element_id][consts.Consts.outgoing_flow] = outgoing_list
 
     @staticmethod
-    def import_task_to_graph(diagram_graph, process_id, process_attributes, element):
+    def import_task_to_graph(diagram_graph, process_id, process_attributes, task_element):
         """
         Adds to graph the new element that represents BPMN task.
         In our representation tasks have only basic attributes and elements, inherited from Activity type,
@@ -363,29 +383,65 @@ class BpmnDiagramGraphImport(object):
         :param process_id: string object, representing an ID of process element,
         :param process_attributes: dictionary that holds attribute values of 'process' element, which is parent of
         imported flow node,
-        :param element: object representing a BPMN XML 'task' element.
+        :param task_element: object representing a BPMN XML 'task' element.
         """
-        BpmnDiagramGraphImport.import_activity_to_graph(diagram_graph, process_id, process_attributes, element)
+        BpmnDiagramGraphImport.import_activity_to_graph(diagram_graph, process_id, process_attributes, task_element)
 
     @staticmethod
-    def import_subprocess_to_graph(diagram_graph, process_id, process_attributes, element):
+    def import_subprocess_to_graph(diagram_graph, sequence_flows, process_id, process_attributes, subprocess_element):
         """
         Adds to graph the new element that represents BPMN subprocess.
         In addition to attributes inherited from FlowNode type, SubProcess
         has additional attribute tiggeredByEvent (boolean type, default value - false).
 
         :param diagram_graph: NetworkX graph representing a BPMN process diagram,
+        :param sequence_flows: a list of sequence flows existing in diagram,
         :param process_id: string object, representing an ID of process element,
         :param process_attributes: dictionary that holds attribute values of 'process' element, which is parent of
         imported flow node,
-        :param element: object representing a BPMN XML 'subprocess' element
+        :param subprocess_element: object representing a BPMN XML 'subprocess' element
         """
-        BpmnDiagramGraphImport.import_activity_to_graph(diagram_graph, process_id, process_attributes, element)
+        BpmnDiagramGraphImport.import_activity_to_graph(diagram_graph, process_id, process_attributes,
+                                                        subprocess_element)
 
-        element_id = element.getAttribute(consts.Consts.id)
-        diagram_graph.node[element_id][consts.Consts.triggered_by_event] = \
-            element.getAttribute(consts.Consts.triggered_by_event) \
-            if element.hasAttribute(consts.Consts.triggered_by_event) else "false"
+        subprocess_id = subprocess_element.getAttribute(consts.Consts.id)
+        diagram_graph.node[subprocess_id][consts.Consts.triggered_by_event] = \
+            subprocess_element.getAttribute(consts.Consts.triggered_by_event) \
+                if subprocess_element.hasAttribute(consts.Consts.triggered_by_event) else "false"
+
+        subprocess_attributes = diagram_graph.node[subprocess_id]
+        subprocess_attributes[consts.Consts.node_ids] = []
+        for element in utils.BpmnImportUtils.iterate_elements(subprocess_element):
+            if element.nodeType != element.TEXT_NODE:
+                tag_name = utils.BpmnImportUtils.remove_namespace_from_tag_name(element.tagName)
+                BpmnDiagramGraphImport.__import_element_by_tag_name(diagram_graph, sequence_flows, subprocess_id,
+                                                                    subprocess_attributes, element, tag_name)
+
+        for flow in utils.BpmnImportUtils.iterate_elements(subprocess_element):
+            if flow.nodeType != flow.TEXT_NODE:
+                tag_name = utils.BpmnImportUtils.remove_namespace_from_tag_name(flow.tagName)
+                if tag_name == consts.Consts.sequence_flow:
+                    BpmnDiagramGraphImport.import_sequence_flow_to_graph(diagram_graph, sequence_flows, subprocess_id,
+                                                                         flow)
+
+    @staticmethod
+    def import_data_object_to_graph(diagram_graph, process_id, process_attributes, data_object_element):
+        """
+        Adds to graph the new element that represents BPMN data object.
+        Data object inherits attributes from FlowNode. In addition, an attribute 'isCollection' is added to the node.
+
+        :param diagram_graph: NetworkX graph representing a BPMN process diagram,
+        :param process_id: string object, representing an ID of process element,
+        :param process_attributes: dictionary that holds attribute values of 'process' element, which is parent of
+        imported flow node,
+        :param data_object_element: object representing a BPMN XML 'dataObject' element.
+        """
+        BpmnDiagramGraphImport.import_flow_node_to_graph(diagram_graph, process_id, process_attributes,
+                                                         data_object_element)
+        data_object_id = data_object_element.getAttribute(consts.Consts.id)
+        diagram_graph.node[data_object_id][consts.Consts.is_collection] = \
+            data_object_element.getAttribute(consts.Consts.is_collection) \
+                if data_object_element.hasAttribute(consts.Consts.is_collection) else "false"
 
     @staticmethod
     def import_activity_to_graph(diagram_graph, process_id, process_attributes, element):
@@ -400,7 +456,7 @@ class BpmnDiagramGraphImport(object):
         imported flow node,
         :param element: object representing a BPMN XML element which extends 'activity'.
         """
-        BpmnDiagramGraphImport.import_flownode_to_graph(diagram_graph, process_id, process_attributes, element)
+        BpmnDiagramGraphImport.import_flow_node_to_graph(diagram_graph, process_id, process_attributes, element)
 
         element_id = element.getAttribute(consts.Consts.id)
         diagram_graph.node[element_id][consts.Consts.default] = element.getAttribute(consts.Consts.default) \
@@ -420,10 +476,10 @@ class BpmnDiagramGraphImport(object):
         :param element: object representing a BPMN XML element of Gateway type extension.
         """
         element_id = element.getAttribute(consts.Consts.id)
-        BpmnDiagramGraphImport.import_flownode_to_graph(diagram_graph, process_id, process_attributes, element)
+        BpmnDiagramGraphImport.import_flow_node_to_graph(diagram_graph, process_id, process_attributes, element)
         diagram_graph.node[element_id][consts.Consts.gateway_direction] = \
             element.getAttribute(consts.Consts.gateway_direction) \
-            if element.hasAttribute(consts.Consts.gateway_direction) else "Unspecified"
+                if element.hasAttribute(consts.Consts.gateway_direction) else "Unspecified"
 
     @staticmethod
     def import_complex_gateway_to_graph(diagram_graph, process_id, process_attributes, element):
@@ -465,7 +521,7 @@ class BpmnDiagramGraphImport(object):
             if element.hasAttribute(consts.Consts.instantiate) else "false"
         diagram_graph.node[element_id][consts.Consts.event_gateway_type] = \
             element.getAttribute(consts.Consts.event_gateway_type) \
-            if element.hasAttribute(consts.Consts.event_gateway_type) else "Exclusive"
+                if element.hasAttribute(consts.Consts.event_gateway_type) else "Exclusive"
 
     @staticmethod
     def import_incl_or_excl_gateway_to_graph(diagram_graph, process_id, process_attributes, element):
@@ -537,13 +593,13 @@ class BpmnDiagramGraphImport(object):
         element_id = element.getAttribute(consts.Consts.id)
         start_event_definitions = {'messageEventDefinition', 'timerEventDefinition', 'conditionalEventDefinition',
                                    'escalationEventDefinition', 'signalEventDefinition'}
-        BpmnDiagramGraphImport.import_flownode_to_graph(diagram_graph, process_id, process_attributes, element)
+        BpmnDiagramGraphImport.import_flow_node_to_graph(diagram_graph, process_id, process_attributes, element)
         diagram_graph.node[element_id][consts.Consts.parallel_multiple] = \
             element.getAttribute(consts.Consts.parallel_multiple) \
-            if element.hasAttribute(consts.Consts.parallel_multiple) else "false"
+                if element.hasAttribute(consts.Consts.parallel_multiple) else "false"
         diagram_graph.node[element_id][consts.Consts.is_interrupting] = \
             element.getAttribute(consts.Consts.is_interrupting) \
-            if element.hasAttribute(consts.Consts.is_interrupting) else "true"
+                if element.hasAttribute(consts.Consts.is_interrupting) else "true"
         BpmnDiagramGraphImport.import_event_definition_elements(diagram_graph, element, start_event_definitions)
 
     @staticmethod
@@ -565,10 +621,10 @@ class BpmnDiagramGraphImport(object):
         intermediate_catch_event_definitions = {'messageEventDefinition', 'timerEventDefinition',
                                                 'signalEventDefinition', 'conditionalEventDefinition',
                                                 'escalationEventDefinition'}
-        BpmnDiagramGraphImport.import_flownode_to_graph(diagram_graph, process_id, process_attributes, element)
+        BpmnDiagramGraphImport.import_flow_node_to_graph(diagram_graph, process_id, process_attributes, element)
         diagram_graph.node[element_id][consts.Consts.parallel_multiple] = \
             element.getAttribute(consts.Consts.parallel_multiple) \
-            if element.hasAttribute(consts.Consts.parallel_multiple) else "false"
+                if element.hasAttribute(consts.Consts.parallel_multiple) else "false"
         BpmnDiagramGraphImport.import_event_definition_elements(diagram_graph, element,
                                                                 intermediate_catch_event_definitions)
 
@@ -588,7 +644,7 @@ class BpmnDiagramGraphImport(object):
         """
         end_event_definitions = {'messageEventDefinition', 'signalEventDefinition', 'escalationEventDefinition',
                                  'errorEventDefinition', 'compensateEventDefinition', 'terminateEventDefinition'}
-        BpmnDiagramGraphImport.import_flownode_to_graph(diagram_graph, process_id, process_attributes, element)
+        BpmnDiagramGraphImport.import_flow_node_to_graph(diagram_graph, process_id, process_attributes, element)
         BpmnDiagramGraphImport.import_event_definition_elements(diagram_graph, element, end_event_definitions)
 
     @staticmethod
@@ -607,10 +663,41 @@ class BpmnDiagramGraphImport(object):
         """
         intermediate_throw_event_definitions = {'messageEventDefinition', 'signalEventDefinition',
                                                 'escalationEventDefinition', 'compensateEventDefinition'}
-        BpmnDiagramGraphImport.import_flownode_to_graph(diagram_graph, process_id, process_attributes, element)
+        BpmnDiagramGraphImport.import_flow_node_to_graph(diagram_graph, process_id, process_attributes, element)
         BpmnDiagramGraphImport.import_event_definition_elements(diagram_graph, element,
                                                                 intermediate_throw_event_definitions)
 
+    @staticmethod
+    def import_boundary_event_to_graph(diagram_graph, process_id, process_attributes, element):
+        """
+        Adds to graph the new element that represents BPMN boundary event.
+        Boundary event inherits sequence of eventDefinitionRef from Event type.
+        Separate methods for each event type are required since each of them has different variants
+        (Message, Error, Signal etc.).
+
+        :param diagram_graph: NetworkX graph representing a BPMN process diagram,
+        :param process_id: string object, representing an ID of process element,
+        :param process_attributes: dictionary that holds attribute values of 'process' element, which is parent of
+        imported flow node,
+        :param element: object representing a BPMN XML 'endEvent' element.
+        """
+        element_id = element.getAttribute(consts.Consts.id)
+        boundary_event_definitions = {'messageEventDefinition', 'timerEventDefinition', 'signalEventDefinition',
+                                      'conditionalEventDefinition', 'escalationEventDefinition', 'errorEventDefinition'}
+        BpmnDiagramGraphImport.import_flow_node_to_graph(diagram_graph, process_id, process_attributes, element)
+
+        diagram_graph.node[element_id][consts.Consts.parallel_multiple] = \
+            element.getAttribute(consts.Consts.parallel_multiple) \
+                if element.hasAttribute(consts.Consts.parallel_multiple) else "false"
+        diagram_graph.node[element_id][consts.Consts.cancel_activity] = \
+            element.getAttribute(consts.Consts.cancel_activity) \
+                if element.hasAttribute(consts.Consts.cancel_activity) else "true"
+        diagram_graph.node[element_id][consts.Consts.attached_to_ref] = \
+            element.getAttribute(consts.Consts.attached_to_ref)
+
+        BpmnDiagramGraphImport.import_event_definition_elements(diagram_graph, element,
+                                                                boundary_event_definitions)
+
     @staticmethod
     def import_sequence_flow_to_graph(diagram_graph, sequence_flows, process_id, flow_element):
         """
@@ -656,15 +743,15 @@ class BpmnDiagramGraphImport(object):
         added when processing nodes, but listing incoming / outgoing nodes under node element is optional - this way
         we can make sure this info will be imported.
         '''
-        if consts.Consts.outgoing_flows not in diagram_graph.node[source_ref]:
-            diagram_graph.node[source_ref][consts.Consts.outgoing_flows] = []
-        outgoing_list = diagram_graph.node[source_ref][consts.Consts.outgoing_flows]
+        if consts.Consts.outgoing_flow not in diagram_graph.node[source_ref]:
+            diagram_graph.node[source_ref][consts.Consts.outgoing_flow] = []
+        outgoing_list = diagram_graph.node[source_ref][consts.Consts.outgoing_flow]
         if flow_id not in outgoing_list:
             outgoing_list.append(flow_id)
 
-        if consts.Consts.incoming_flows not in diagram_graph.node[target_ref]:
-            diagram_graph.node[target_ref][consts.Consts.incoming_flows] = []
-        incoming_list = diagram_graph.node[target_ref][consts.Consts.incoming_flows]
+        if consts.Consts.incoming_flow not in diagram_graph.node[target_ref]:
+            diagram_graph.node[target_ref][consts.Consts.incoming_flow] = []
+        incoming_list = diagram_graph.node[target_ref][consts.Consts.incoming_flow]
         if flow_id not in incoming_list:
             incoming_list.append(flow_id)
 
@@ -703,15 +790,15 @@ class BpmnDiagramGraphImport(object):
         added when processing nodes, but listing incoming / outgoing nodes under node element is optional - this way
         we can make sure this info will be imported.
         '''
-        if consts.Consts.outgoing_flows not in diagram_graph.node[source_ref]:
-            diagram_graph.node[source_ref][consts.Consts.outgoing_flows] = []
-        outgoing_list = diagram_graph.node[source_ref][consts.Consts.outgoing_flows]
+        if consts.Consts.outgoing_flow not in diagram_graph.node[source_ref]:
+            diagram_graph.node[source_ref][consts.Consts.outgoing_flow] = []
+        outgoing_list = diagram_graph.node[source_ref][consts.Consts.outgoing_flow]
         if flow_id not in outgoing_list:
             outgoing_list.append(flow_id)
 
-        if consts.Consts.incoming_flows not in diagram_graph.node[target_ref]:
-            diagram_graph.node[target_ref][consts.Consts.incoming_flows] = []
-        incoming_list = diagram_graph.node[target_ref][consts.Consts.incoming_flows]
+        if consts.Consts.incoming_flow not in diagram_graph.node[target_ref]:
+            diagram_graph.node[target_ref][consts.Consts.incoming_flow] = []
+        incoming_list = diagram_graph.node[target_ref][consts.Consts.incoming_flow]
         if flow_id not in incoming_list:
             incoming_list.append(flow_id)
 
@@ -740,10 +827,10 @@ class BpmnDiagramGraphImport(object):
             if node[consts.Consts.type] == consts.Consts.subprocess:
                 node[consts.Consts.is_expanded] = \
                     shape_element.getAttribute(consts.Consts.is_expanded) \
-                    if shape_element.hasAttribute(consts.Consts.is_expanded) else "false"
+                        if shape_element.hasAttribute(consts.Consts.is_expanded) else "false"
             node[consts.Consts.x] = bounds.getAttribute(consts.Consts.x)
             node[consts.Consts.y] = bounds.getAttribute(consts.Consts.y)
-        elif element_id in participants_dict:
+        if element_id in participants_dict:
             # BPMNShape is either connected with FlowNode or Participant
             participant_attr = participants_dict[element_id]
             participant_attr[consts.Consts.is_horizontal] = shape_element.getAttribute(consts.Consts.is_horizontal)
@@ -779,15 +866,18 @@ class BpmnDiagramGraphImport(object):
                             waypoints_xml[index].getAttribute(consts.Consts.y))
             waypoints[index] = waypoint_tmp
 
+        flow_data = None
         if flow_id in sequence_flows:
             flow_data = sequence_flows[flow_id]
-        else:
+        elif flow_id in message_flows:
             flow_data = message_flows[flow_id]
-        name = flow_data[consts.Consts.name]
-        source_ref = flow_data[consts.Consts.source_ref]
-        target_ref = flow_data[consts.Consts.target_ref]
-        diagram_graph.edge[source_ref][target_ref][consts.Consts.waypoints] = waypoints
-        diagram_graph.edge[source_ref][target_ref][consts.Consts.name] = name
+
+        if flow_data is not None:
+            name = flow_data[consts.Consts.name]
+            source_ref = flow_data[consts.Consts.source_ref]
+            target_ref = flow_data[consts.Consts.target_ref]
+            diagram_graph.edge[source_ref][target_ref][consts.Consts.waypoints] = waypoints
+            diagram_graph.edge[source_ref][target_ref][consts.Consts.name] = name
 
     @staticmethod
     def read_xml_file(filepath):
