@@ -21,11 +21,14 @@ class Consts(object):
     target_ref = "targetRef"
     triggered_by_event = "triggeredByEvent"
     parallel_multiple = "parallelMultiple"
+    cancel_activity = "cancelActivity"
+    attached_to_ref = "attachedToRef"
     is_interrupting = "isInterrupting"
     is_closed = "isClosed"
     is_executable = "isExecutable"
     is_expanded = "isExpanded"
     is_horizontal = "isHorizontal"
+    is_collection = "isCollection"
     process_type = "processType"
     sequence_flow = "sequenceFlow"
     condition_expression = "conditionExpression"
@@ -40,7 +43,6 @@ class Consts(object):
     csv_subprocess = "Subprocess"
     csv_terminated = "Terminated"
 
-
     # BPMN 2.0 diagram interchange element attribute names
     bpmn_element = "bpmnElement"
     height = "height"
@@ -62,7 +64,11 @@ class Consts(object):
     flow_node_ref = "flowNodeRef"
     flow_node_refs = "flowNodeRefs"
     task = "task"
+    user_task = "userTask"
+    service_task = "serviceTask"
+    manual_task = "manualTask"
     subprocess = "subProcess"
+    data_object = "dataObject"
     complex_gateway = "complexGateway"
     event_based_gateway = "eventBasedGateway"
     inclusive_gateway = "inclusiveGateway"
@@ -72,14 +78,17 @@ class Consts(object):
     intermediate_catch_event = "intermediateCatchEvent"
     end_event = "endEvent"
     intermediate_throw_event = "intermediateThrowEvent"
+    boundary_event = "boundaryEvent"
 
     # BPMN 2.0 diagram interchange element names
     bpmn_shape = "BPMNShape"
     bpmn_edge = "BPMNEdge"
 
     # BPMN 2.0 child element names
-    incoming_flows = "incoming"
-    outgoing_flows = "outgoing"
+    incoming_flow = "incoming"
+    incoming_flow_list = "incoming_flow_list"
+    outgoing_flow = "outgoing"
+    outgoing_flow_list = "outgoing_flow_list"
     waypoint = "waypoint"
     waypoints = "waypoints"
 
